@@ -1,8 +1,8 @@
-//! SD24_B4
+//! SD24_B3
 
 utils::periph! {
-    /// SD24_B4
-    SD24_B4;
+    /// SD24_B3
+    SD24_B3;
     /// SD24B Control Register 0
     rw SD24BCTL0 @ 0x00: u16 = 0_0 {
         /// SD24B Overflow Control
@@ -86,66 +86,6 @@ utils::periph! {
             SD24DMA_8 = 0b1000,
         }
     }
-    /// SD24B Trigger Control Register
-    rw SD24BTRGCTL @ 0x04: u16 = 0_0 {
-        /// SD24B Start Conversion
-        SD24BTRGCTL_SD24SC: 0 = struct SD24BTRGCTL_SD24SC(bool);
-        /// SD24B Start Conversion Select Bit 0
-        SD24BTRGCTL_SD24SCS: 1..3 = enum SD24BTRGCTL_SD24SCS {
-            /// SD24B Start Conversion Select: 0
-            SD24SCS_0 = 0b000,
-            /// SD24B Start Conversion Select: 1
-            SD24SCS_1 = 0b001,
-            /// SD24B Start Conversion Select: 2
-            SD24SCS_2 = 0b010,
-            /// SD24B Start Conversion Select: 3
-            SD24SCS_3 = 0b011,
-            /// SD24B Start Conversion Select: 4
-            SD24SCS_4 = 0b100,
-            /// SD24B Start Conversion Select: 5
-            SD24SCS_5 = 0b101,
-            /// SD24B Start Conversion Select: 6
-            SD24SCS_6 = 0b110,
-            /// SD24B Start Conversion Select: 7
-            SD24SCS_7 = 0b111,
-        }
-        /// SD24B Single Trigger Mode
-        SD24BTRGCTL_SD24SNGL: 8 = struct SD24BTRGCTL_SD24SNGL(bool);
-        /// SD24B Trigger Interrupt Flag
-        SD24TRGIFG: 10 = struct SD24TRGIFG(bool);
-        /// SD24B Trigger Interrupt Enable
-        SD24TRGIE: 11 = struct SD24TRGIE(bool);
-    }
-    /// SD24B Trigger OSR Control Register
-    rw SD24BTRGOSR @ 0x06: u16 = 0_0 {
-        /// SD24B Oversampling Rate Bit: 0
-        SD24BTRGOSR_OSR0: 0 = struct SD24BTRGOSR_OSR0(bool);
-        /// SD24B Oversampling Rate Bit: 1
-        SD24BTRGOSR_OSR1: 1 = struct SD24BTRGOSR_OSR1(bool);
-        /// SD24B Oversampling Rate Bit: 2
-        SD24BTRGOSR_OSR2: 2 = struct SD24BTRGOSR_OSR2(bool);
-        /// SD24B Oversampling Rate Bit: 3
-        SD24BTRGOSR_OSR3: 3 = struct SD24BTRGOSR_OSR3(bool);
-        /// SD24B Oversampling Rate Bit: 4
-        SD24BTRGOSR_OSR4: 4 = struct SD24BTRGOSR_OSR4(bool);
-        /// SD24B Oversampling Rate Bit: 5
-        SD24BTRGOSR_OSR5: 5 = struct SD24BTRGOSR_OSR5(bool);
-        /// SD24B Oversampling Rate Bit: 6
-        SD24BTRGOSR_OSR6: 6 = struct SD24BTRGOSR_OSR6(bool);
-        /// SD24B Oversampling Rate Bit: 7
-        SD24BTRGOSR_OSR7: 7 = struct SD24BTRGOSR_OSR7(bool);
-        /// SD24B Oversampling Rate Bit: 8
-        SD24BTRGOSR_OSR8: 8 = struct SD24BTRGOSR_OSR8(bool);
-        /// SD24B Oversampling Rate Bit: 9
-        SD24BTRGOSR_OSR9: 9 = struct SD24BTRGOSR_OSR9(bool);
-        /// SD24B Oversampling Rate Bit: 10
-        SD24BTRGOSR_OSR10: 10 = struct SD24BTRGOSR_OSR10(bool);
-    }
-    /// SD24B Trigger Preload Register
-    rw SD24BTRGPRE @ 0x08: u16 = 0_0 {
-        /// SD24B Trigger Preload Register
-        SD24BTRGPRE: 0..15 = struct SD24BTRGPREField(u16);
-    }
     /// SD24B Interrupt Flag Register
     rw SD24BIFG @ 0x0a: u16 = 0_0 {
         /// SD24B Channel 0 Interrupt Flag
@@ -154,16 +94,12 @@ utils::periph! {
         SD24IFG1: 1 = struct SD24IFG1(bool);
         /// SD24B Channel 2 Interrupt Flag
         SD24IFG2: 2 = struct SD24IFG2(bool);
-        /// SD24B Channel 3 Interrupt Flag
-        SD24IFG3: 3 = struct SD24IFG3(bool);
         /// SD24B Channel 0 Overflow Interrupt Flag
         SD24OVIFG0: 8 = struct SD24OVIFG0(bool);
         /// SD24B Channel 1 Overflow Interrupt Flag
         SD24OVIFG1: 9 = struct SD24OVIFG1(bool);
         /// SD24B Channel 2 Overflow Interrupt Flag
         SD24OVIFG2: 10 = struct SD24OVIFG2(bool);
-        /// SD24B Channel 3 Overflow Interrupt Flag
-        SD24OVIFG3: 11 = struct SD24OVIFG3(bool);
     }
     /// SD24B Interrupt Enable Register
     rw SD24BIE @ 0x0c: u16 = 0_0 {
@@ -173,16 +109,12 @@ utils::periph! {
         SD24IE1: 1 = struct SD24IE1(bool);
         /// SD24B Channel 2 Interrupt Enable
         SD24IE2: 2 = struct SD24IE2(bool);
-        /// SD24B Channel 3 Interrupt Enable
-        SD24IE3: 3 = struct SD24IE3(bool);
         /// SD24B Channel 0 Overflow Interrupt Enable
         SD24OVIE0: 8 = struct SD24OVIE0(bool);
         /// SD24B Channel 1 Overflow Interrupt Enable
         SD24OVIE1: 9 = struct SD24OVIE1(bool);
         /// SD24B Channel 2 Overflow Interrupt Enable
         SD24OVIE2: 10 = struct SD24OVIE2(bool);
-        /// SD24B Channel 3 Overflow Interrupt Enable
-        SD24OVIE3: 11 = struct SD24OVIE3(bool);
     }
     /// SD24B Interrupt Vector Register
     rw SD24BIV @ 0x0e: u16 = 0_0 {
@@ -561,130 +493,6 @@ utils::periph! {
         /// SD24B Channel 2 Preload Register
         SD24BPRE2: 0..15 = struct SD24BPRE2Field(u16);
     }
-    /// SD24B Channel 3 Control Register
-    rw SD24BCCTL3 @ 0x28: u16 = 0_0 {
-        /// SD24B Start Conversion
-        SD24BCCTL3_SD24SC: 0 = struct SD24BCCTL3_SD24SC(bool);
-        /// SD24B Start Conversion Select Bit 0
-        SD24BCCTL3_SD24SCS: 1..3 = enum SD24BCCTL3_SD24SCS {
-            /// SD24B Start Conversion Select: 0
-            SD24SCS_0 = 0b000,
-            /// SD24B Start Conversion Select: 1
-            SD24SCS_1 = 0b001,
-            /// SD24B Start Conversion Select: 2
-            SD24SCS_2 = 0b010,
-            /// SD24B Start Conversion Select: 3
-            SD24SCS_3 = 0b011,
-            /// SD24B Start Conversion Select: 4
-            SD24SCS_4 = 0b100,
-            /// SD24B Start Conversion Select: 5
-            SD24SCS_5 = 0b101,
-            /// SD24B Start Conversion Select: 6
-            SD24SCS_6 = 0b110,
-            /// SD24B Start Conversion Select: 7
-            SD24SCS_7 = 0b111,
-        }
-        /// SD24B Data Format Bit: 0
-        SD24BCCTL3_SD24DF: 4..5 = enum SD24BCCTL3_SD24DF {
-            /// SD24B Data Format: Offset Binary
-            SD24DF_0 = 0b00,
-            /// SD24B Data Format: 2's complement
-            SD24DF_1 = 0b01,
-        }
-        /// SD24B Data Alignment
-        SD24BCCTL3_SD24ALGN: 6 = struct SD24BCCTL3_SD24ALGN(bool);
-        /// SD24B Single Trigger Mode
-        SD24BCCTL3_SD24SNGL: 8 = struct SD24BCCTL3_SD24SNGL(bool);
-        /// SD24B Calibration
-        SD24BCCTL3_SD24CAL: 9 = struct SD24BCCTL3_SD24CAL(bool);
-        /// SD24B Digital Filter Bit: 0
-        SD24BCCTL3_SD24DFS: 10..11 = enum SD24BCCTL3_SD24DFS {
-            /// SD24B Digital Filter 0
-            SD24DFS_0 = 0b00,
-            /// SD24B Digital Filter 1
-            SD24DFS_1 = 0b01,
-            /// SD24B Digital Filter 2
-            SD24DFS_2 = 0b10,
-            /// SD24B Digital Filter 3
-            SD24DFS_3 = 0b11,
-        }
-        /// SD24B Digital Bitstream Input
-        SD24BCCTL3_SD24DI: 12 = struct SD24BCCTL3_SD24DI(bool);
-        /// SD24B Manchaster Encoding Bit: 0
-        SD24BCCTL3_SD24MC: 13..14 = enum SD24BCCTL3_SD24MC {
-            /// SD24B Manchaster Encoding 0
-            SD24MC_0 = 0b00,
-            /// SD24B Manchaster Encoding 1
-            SD24MC_1 = 0b01,
-            /// SD24B Manchaster Encoding 2
-            SD24MC_2 = 0b10,
-            /// SD24B Manchaster Encoding 3
-            SD24MC_3 = 0b11,
-        }
-    }
-    /// SD24B Channel 3 Input Control Register
-    rw SD24BINCTL3 @ 0x2a: u16 = 0_0 {
-        /// SD24B Input Pre-Amplifier Gain Select 0
-        SD24BINCTL3_SD24GAIN: 3..5 = enum SD24BINCTL3_SD24GAIN {
-            /// SD24B Input Pre-Amplifier Gain Select *1
-            SD24GAIN_1 = 0b000,
-            /// SD24B Input Pre-Amplifier Gain Select *2
-            SD24GAIN_2 = 0b001,
-            /// SD24B Input Pre-Amplifier Gain Select *4
-            SD24GAIN_4 = 0b010,
-            /// SD24B Input Pre-Amplifier Gain Select *8
-            SD24GAIN_8 = 0b011,
-            /// SD24B Input Pre-Amplifier Gain Select *16
-            SD24GAIN_16 = 0b100,
-            /// SD24B Input Pre-Amplifier Gain Select *32
-            SD24GAIN_32 = 0b101,
-            /// SD24B Input Pre-Amplifier Gain Select *64
-            SD24GAIN_64 = 0b110,
-            /// SD24B Input Pre-Amplifier Gain Select *128
-            SD24GAIN_128 = 0b111,
-        }
-        /// SD24B Interrupt Delay after 1.Conversion 0
-        SD24BINCTL3_SD24INTDLY: 6..7 = enum SD24BINCTL3_SD24INTDLY {
-            /// SD24B Interrupt Delay: Int. after 4.Conversion
-            SD24INTDLY_0 = 0b00,
-            /// SD24B Interrupt Delay: Int. after 3.Conversion
-            SD24INTDLY_1 = 0b01,
-            /// SD24B Interrupt Delay: Int. after 2.Conversion
-            SD24INTDLY_2 = 0b10,
-            /// SD24B Interrupt Delay: Int. after 1.Conversion
-            SD24INTDLY_3 = 0b11,
-        }
-    }
-    /// SD24B Channel 3 OSR Control Register
-    rw SD24BOSR3 @ 0x2c: u16 = 0_0 {
-        /// SD24B Oversampling Rate Bit: 0
-        SD24BOSR3_OSR0: 0 = struct SD24BOSR3_OSR0(bool);
-        /// SD24B Oversampling Rate Bit: 1
-        SD24BOSR3_OSR1: 1 = struct SD24BOSR3_OSR1(bool);
-        /// SD24B Oversampling Rate Bit: 2
-        SD24BOSR3_OSR2: 2 = struct SD24BOSR3_OSR2(bool);
-        /// SD24B Oversampling Rate Bit: 3
-        SD24BOSR3_OSR3: 3 = struct SD24BOSR3_OSR3(bool);
-        /// SD24B Oversampling Rate Bit: 4
-        SD24BOSR3_OSR4: 4 = struct SD24BOSR3_OSR4(bool);
-        /// SD24B Oversampling Rate Bit: 5
-        SD24BOSR3_OSR5: 5 = struct SD24BOSR3_OSR5(bool);
-        /// SD24B Oversampling Rate Bit: 6
-        SD24BOSR3_OSR6: 6 = struct SD24BOSR3_OSR6(bool);
-        /// SD24B Oversampling Rate Bit: 7
-        SD24BOSR3_OSR7: 7 = struct SD24BOSR3_OSR7(bool);
-        /// SD24B Oversampling Rate Bit: 8
-        SD24BOSR3_OSR8: 8 = struct SD24BOSR3_OSR8(bool);
-        /// SD24B Oversampling Rate Bit: 9
-        SD24BOSR3_OSR9: 9 = struct SD24BOSR3_OSR9(bool);
-        /// SD24B Oversampling Rate Bit: 10
-        SD24BOSR3_OSR10: 10 = struct SD24BOSR3_OSR10(bool);
-    }
-    /// SD24B Channel 3 Preload Register
-    rw SD24BPRE3 @ 0x2e: u16 = 0_0 {
-        /// SD24B Channel 3 Preload Register
-        SD24BPRE3: 0..15 = struct SD24BPRE3Field(u16);
-    }
     /// SD24B Channel 0 Conversion Memory Low word
     rw SD24BMEML0 @ 0x50: u16 = 0_0 {
         /// SD24B Channel 0 Conversion Memory Low word
@@ -715,14 +523,4 @@ utils::periph! {
         /// SD24B Channel 2 Conversion Memory High Word
         SD24BMEMH2: 0..15 = struct SD24BMEMH2Field(u16);
     }
-    /// SD24B Channel 3 Conversion Memory Low word
-    rw SD24BMEML3 @ 0x5c: u16 = 0_0 {
-        /// SD24B Channel 3 Conversion Memory Low word
-        SD24BMEML3: 0..15 = struct SD24BMEML3Field(u16);
-    }
-    /// SD24B Channel 3 Conversion Memory High Word
-    rw SD24BMEMH3 @ 0x5e: u16 = 0_0 {
-        /// SD24B Channel 3 Conversion Memory High Word
-        SD24BMEMH3: 0..15 = struct SD24BMEMH3Field(u16);
-    }
 }
